Pro cieloagn, PS=ps, ENC=enc, PORT=port, MONO=mono, GRID=grid, TOPLABEL=toplab
;+
; AITOFF projection of extragalactic EGRET sources (identified or not)
;
; if "ps" is set then plot to "cieloagn.ps"/"cieloagn_bw.ps"
; if "enc" is set then use Encapsulated PS file
; if "port" is set then use portrait orientated PS file
; if "mono" is set then use B/W color table
; if "grid" is set then overplot RA/DEC grid
; if "toplab" is set then mark plot with a top label
;
; LN, 1997   ( Last change: 10/3/2001 )
;-

  a = nxyreadf('egret_id.dat') ; 65 sources
  ra1 = a[0,*]                 ; ra1 / gl1 if RA / l in the file
  dec1 = a[1,*]                ; dec1 / gb1 if DEC / b in the file
  gl1 = ra1
  gb1 = dec1
  ns1 = N_ELEMENTS(ra1)
  a=nxyreadf('egret_nid.dat')   ; 10 sources
  ra2 = a[0,*]
  dec2 = a[1,*]
  gl2 = ra2
  gb2 = dec2
  ns2 = N_ELEMENTS(ra2)
;
; Define a 19 color table
  c = loadct19(ps=ps,mono=mono)

;
  tf = 1
  xyouts,0,0,'!17',/norm     ; dummy call to set vector font 17
  pcsav = !P.COLOR           ; save for restoring
  pbsav = !P.BACKGROUND      ; save for restoring
  if (keyword_set(mono) and not keyword_set(ps)) then $
    c[0:17] = 0;

  !P.COLOR = c[0]
  !p.background = c[18]

  if keyword_set(ps) then begin
    tf = 2
    odev = !d.name
    !p.color = 0
    set_plot,'ps'
    device, file='cieloagn.ps', /color, ENCAP=enc
; Portrait or Landscape but preserving the aspect ratio 26./14 = 19.5/10.5
    if keyword_set(port) then device, /port,xoff=0,yoff=10,xsize=19.5,ysize=10.5 $
    else device, /land,yoff=28,xsize=26,ysize=14
    device, /times, font_index=17
    device, /helvetica, /bold, /oblique, font_index=18
  endif else begin
    ps = 0
    window, xs=900, ys=500
  endelse

; Uncomment below if RA and DEC in the files
  for i=0,ns1-1 do begin
    glactc, ra1[i]/15., dec1[i], 2000., l, b, 1
    gl1[i] = l
    gb1[i] = b
  endfor

  aitoff, gl1, gb1, x1, y1

; Filled circle
  pp = findgen(32)*(!pi*2/31.)
  usersym, cos(pp), sin(pp), /fill
;
  plot, x1, y1, psym=8, xstyle=4, ystyle=4, color=c[2]  ; back=5

  aitoff_grid2, 30, 15, label=1       ; AITOFF grid with corner values

  plots,0.30,0.05, psym=8, symsize=1.5, color=c[2], /norm
  xyouts,0.31,0.03,'!17Identified AGNs',charsize=1.5, charthick=tf, $
         font=ps-1, /norm

; Uncomment below if RA and DEC in the files
  for i = 0,ns2-1 do begin
    glactc, ra2[i]/15., dec2[i], 2000., l, b, 1
    gl2[i] = l
    gb2[i] = b
  endfor

  aitoff, gl2, gb2, x2, y2

  oplot, x2, y2, psym=8, color=c[7]
  plots, 0.60, 0.05, psym=8, symsize=1.5, color=c[7], /norm

; Overplot an empty circle
  USERSYM,COS(pp),SIN(pp), thick=tf*2

  oplot, x2, y2, psym=8, color=c[3]
  plots, 0.60, 0.05, psym=8, symsize=1.5, color=c[3], /norm
  xyouts, 0.61, 0.03,'!17Unidentified',chars=1.5, charthick=tf, font=ps-1, /norm

; Top label
  if KEYWORD_SET(toplab) then $
    xyouts, 0.5, 0.97, '!18AGNs and unidentified EGRET (3EG)', $
           charsize=1.8, charthick=tf, align=.5, font=ps-1, /norm


  if keyword_set(grid) then begin
    ggl = fltarr(181)
    ggb = fltarr(181)
    for j=0,24 do begin
     for i=0,180 do begin
        glactc, j, i-90, 1950., l, b, 1
        ggl[i] = l
        ggb[i] = b
     endfor
     aitoff, ggl, ggb, x, y
     oplot, x, y, psym=3
    endfor

    gggl = fltarr(241)
    gggb = fltarr(241)
    for i = 0,240 do begin
        glactc, i/10., 0, 2000., l, b, 1
        gggl[i] = l
        gggb[i] = b
    endfor
    aitoff, gggl, gggb, x, y
    oplot, x, y, psym=3
  endif
;

; Mark the poles
  glactc, 0., 90., 2000.0, la, b,1
  aitoff, la, b, xi, yi
  plots, xi, yi, psym=1, symsize=1.5, thick=2
  glactc, 0., -90., 2000.0, la, b,1
  aitoff, la, b, xi, yi
  plots, xi, yi, psym=1, symsize=1.5, thick=2

; Draws the DEC = -10, +70 strip
  gl1 = fltarr(200)  &  gb1 = gl1  &  gb2 = gl1  &  gl2 = gl1
  ra1 = findgen(200) * 24./199.
  for i = 0,199 do begin
    glactc, ra1[i], -10, 2000., l, b, 1
    gl1[i] = l
    gb1[i] = b
  endfor

  ii = sort(gl1)
  gl1 = gl1[ii]
  gb1 = gb1[ii]
  i = where(gl1 gt 180)
  i = i[0]
  gl1 = [gl1[i:199],gl1[0:i-1]]
  gb1 = [gb1[i:199],gb1[0:i-1]]

  aitoff, gl1, gb1, x1, y1
  plots, x1, y1, color=c[4], thick=tf*4

  gla = fltarr(100) + 180.
  gba = gb1[199] + findgen(100) * (-90.-gb1[199])/48.
  aitoff, gla, gba, xx, yy
  plots, xx, yy, color=c[4], thick=tf*4

  polyfill, [x1,xx],[y1,yy], /line_fill, orient=45, thick=tf*2, color=c[5]

  for i = 0,199 do begin
    glactc, ra1[i], 70, 2000., l, b, 1
    gl2[i] = l
    gb2[i] = b
  endfor
  aitoff, gl2, gb2, x2, y2
;  oplot,x2,y2,psym=1,syms=.1,color=3,thick=tf*4
  plots, x2, y2, color=c[4], thick=tf*4
  polyfill, x2, y2, /line_fill, orient=45, thick=tf*2, color=c[5]

  xyouts,.78,.12,'!17Dec=-10!Uo!N', chars=1.5, charthick=tf, font=ps-1, /norm
  cv=convert_coord(.77,.125,/NORM,/TO_DEV)
  one_arrow,cv[0],cv[1],170,'',ARROWSIZE=[5.5*!D.Y_CH_SIZE,!D.Y_CH_SIZE,30]

  xyouts,.82,.84,'!17Dec=+70!Uo!N', chars=1.5, charthick=tf, font=ps-1, /norm
  cv=convert_coord(.84,.825,/NORM,/TO_DEV)
  one_arrow,cv[0],cv[1],240,'',ARROWSIZE=[4.5*!D.Y_CH_SIZE,!D.Y_CH_SIZE,30]

  !P.COLOR = pcsav          ; restore
  !P.BACKGROUND = pbsav     ; restore

  if keyword_set(ps) then begin
    device, /close
    set_plot, odev
    print, 'File "cieloagn.ps" ready.'
  endif

return
end
