Pro crabpulse, PS=ps, ENC=enc, PORT=port, MONO=mono, TOPLAB=toplab, _EXTRA=e
;+
; Plot the Crab pulse+photon index for BSAX LECS+MECS+HP+PDS
;
; INPUT KEYWORDS:
;
;   if "ps" is set then plot to "crabpulse.ps"/"crabpulse_bw.ps"
;   if "enc" is set then use Encapsulated PS file
;   if "port" is set then use portrait orientated PS file
;   if "mono" is set then plot in B/W
;   if "toplab" is set then mark plot with a top label
;
;   + any keyword allowed by PLOTS
;
; L. Nicastro @ IFCAI-CNR, June 1999.
;-

  tf = 1  ; default line thickness
  col = loadct19(MONO=mono, PS=ps)  ; define 19 colors for color index 0-18

  if not keyword_set(ps) then window, xsiz=800, ysiz=600

  if keyword_set(toplab) then topl = '!18Crab pulsar!17' else topl = ''

  if keyword_set(ps) then begin
    if keyword_set(mono) then psfile = 'crabpulse_bw.ps' $
                         else psfile = 'crabpulse.ps'

    tf = 4
    odev = !d.name
    set_plot, 'ps'
    if keyword_set(port) then $
      device, file=psfile,/port,encap=enc,xsize=19.5,ysize=22,xoff=1,yoff=2 $
    else $
      device, file=psfile,/land,encap=enc,xsize=26.,ysize=17,xoff=2,yoff=26.6
    if not keyword_set(mono) then device, /color
  endif

  pos = pposn(4,2,/YFIRST)   ; 4x2 plot top-to-bottom

  xyouts,0,0,'!17',/norm     ; dummy call to set vector font 17

; LECS 0.5-8 keV pulse profile
  a = lcqdpread('crab_lepulse.qdp',/phase)
  a[2,*] = a[2,*]/MAX(a[2,*])

  plot, a[0,*]-1, a[2,*], /NODATA, xsty=1, ysty=1, psym=10, chars=1.5, $
        xrange=[-0.30,0.80], yrange=[0.5,1.05], $
        thick=tf, xthick=tf, ythick=tf, $ ;title=topl, $
        xticks=4, xminor=4, xtickv=[-.25,0,.25,.5,.75], $
        yminor=5, ytitle='!17Normalized cts/s', color=col[0], $
        position=pos[0,*], xtickname=[' ',' ',' ',' ',' ',' ',' ']

  binplot, a[0,*]-1, a[2,*], color=col[2], thick=tf, /connect, _EXTRA=e

; Mark data
  xyouts, 0.5, 1.00, '!18 LECS!17', chars=1.3, color=col[2], align=.5
  xyouts, 0.5, 0.94, '!18 0.5-8!17', chars=1.3, color=col[2], align=.5

; LECS photon index
  a = lcqdpread('crab_lephin.qdp',/phase)

  plot, a[0,*], a[2,*], /NODATA, /NOERASE, xsty=1, ysty=1, chars=1.5, $
        xrange=[-0.30,0.80], yrange=[1.1,2.15], $
        thick=tf, xthick=tf, ythick=tf, $
        xticks=4, xminor=4, xtickv=[-.25,0,.25,.5,.75], $
        ytitle='!17Photon index', color=col[0], $
        position=pos[1,*], $ ;xtitle='!17Pulse Phase', $
        xtickname=['-0.25','0','0.25','0.5','0.75']

  binplot, a[0,*], a[2,*], a[1,*], color=col[2], thick=tf, _EXTRA=e
  erplot, a[0,*], a[2,*], a[3,*], color=col[2], thick=tf, width=0.0

; MECS 2-10 keV pulse profile
  a = lcqdpread('crab_mepulse.qdp',/phase)
  a[2,*] = a[2,*]/MAX(a[2,*])

  plot, a[0,*]-1, a[2,*], /NODATA, /NOERA, xsty=1, ysty=1, psym=10, chars=1.5, $
        xrange=[-0.30,0.80], yrange=[0.5,1.05], $
        thick=tf, xthick=tf, ythick=tf, $ ;title= topl, $
        xticks=4, xminor=4, xtickv=[-.25,0,.25,.5,.75], $
        yminor=5, ytickname=[' ',' ',' ',' ',' ',' ',' '], color=col[0], $
        position=pos[2,*], xtickname=[' ',' ',' ',' ',' ',' ',' ']

  binplot, a[0,*]-1, a[2,*], color=col[17], thick=tf, /connect, _EXTRA=e

; Mark data
  xyouts, 0.5, 1.00, '!18 MECS!17', chars=1.3, color=col[17], align=.5
  xyouts, 0.5, 0.94, '!18 1-10!17', chars=1.3, color=col[17], align=.5

; MECS photon index
  a = lcqdpread('crab_mephin.qdp',/phase)

  plot, a[0,*], a[2,*], /NODATA, /NOERASE, xsty=1, ysty=1, chars=1.5, $
        xrange=[-0.30,0.80], yrange=[1.1,2.15], $
        thick=tf, xthick=tf, ythick=tf, $
        xticks=4, xminor=4, xtickv=[-.25,0,.25,.5,.75], $
        ytickname=[' ',' ',' ',' ',' ',' ',' '], color=col[0], $
        position=pos[3,*], $ ;xtitle='!17Pulse Phase', $
        xtickname=[' ','0','0.25','0.5','0.75']

  binplot, a[0,*], a[2,*], a[1,*], color=col[17], thick=tf, _EXTRA=e
  erplot, a[0,*], a[2,*], a[3,*], color=col[17], thick=tf, width=0.0

; HP 10-34 keV pulse profile
  a = lcqdpread('crab_hppulse.qdp',/phase)
  a[2,*] = a[2,*]/MAX(a[2,*])

  plot, a[0,*]-1, a[2,*], /NODATA, /NOERA, xsty=1, ysty=1, psym=10, chars=1.5, $
        xrange=[-0.30,0.80], yrange=[0.5,1.05], $
        thick=tf, xthick=tf, ythick=tf, $ ;title= topl, $
        xticks=4, xminor=4, xtickv=[-.25,0,.25,.5,.75], $
        yminor=5, color=col[0], ytickname=[' ',' ',' ',' ',' ',' ',' '], $
        position=pos[4,*], xtickname=[' ',' ',' ',' ',' ',' ',' ']

  binplot, a[0,*]-1, a[2,*], color=col[4], thick=tf, /connect, _EXTRA=e

; The single title
  xyouts, -0.3, 1.07, topl, chars=1.5, color=col[0], align=.5

; Mark data
  xyouts, 0.5, 1.00, '!18 HP!17', chars=1.3, color=col[4], align=.5
  xyouts, 0.5, 0.94, '!18 10-34!17', chars=1.3, color=col[4], align=.5

; HP photon index
  a = lcqdpread('crab_hpphin.qdp',/phase)

  plot, a[0,*], a[2,*], /NODATA, /NOERASE, xsty=1, ysty=1, chars=1.5, $
        xrange=[-0.30,0.80], yrange=[1.1,2.15], $
        thick=tf, xthick=tf, ythick=tf, $
        xticks=4, xminor=4, xtickv=[-.25,0,.25,.5,.75], $
        color=col[0], ytickname=[' ',' ',' ',' ',' ',' ',' '], $
        position=pos[5,*], $ ;xtitle='!17Pulse Phase!6', $
        xtickname=[' ','0','0.25','0.5','0.75']

  binplot, a[0,*], a[2,*], a[1,*], color=col[4], thick=tf, _EXTRA=e
  erplot, a[0,*], a[2,*], a[3,*], color=col[4], thick=tf, width=0.0

; The single X label
  xyouts, -0.3, 0.90, '!17Pulse Phase!6', chars=1.5, color=col[0], align=.5

; PDS 15-200 keV pulse profile
  a = lcqdpread('crab_pdspulse.qdp',/phase)
  a[2,*] = a[2,*]/MAX(a[2,*])

  plot, a[0,*]-1, a[2,*], /NODATA, /NOERA, xsty=1, ysty=1, psym=10, chars=1.5, $
        xrange=[-0.30,0.80], yrange=[0.5,1.05], $
        thick=tf, xthick=tf, ythick=tf, $ ;title= topl, $
        xticks=4, xminor=4, xtickv=[-.25,0,.25,.5,.75], $
        yminor=5, color=col[0], ytickname=[' ',' ',' ',' ',' ',' ',' '], $
        position=pos[6,*], xtickname=[' ',' ',' ',' ',' ',' ',' ']

  binplot, a[0,*]-1, a[2,*], color=col[5], thick=tf, /connect, _EXTRA=e

; Mark data

  xyouts, 0.5, 1.00, '!18 PDS!17', chars=1.3, color=col[5], align=.5
  xyouts, 0.5, 0.94, '!18 15-200!17', chars=1.3, color=col[5], align=.5

; PDS photon index
  a  = lcqdpread('crab_pdsphin.qdp',/phase)

  plot, a[0,*], a[2,*], /NODATA, /NOERASE, xsty=1, ysty=1, chars=1.5, $
        xrange=[-0.30,0.80], yrange=[1.1,2.15], $
        thick=tf, xthick=tf, ythick=tf, $
        xticks=4, xminor=4, xtickv=[-.25,0,.25,.5,.75], $
        color=col[0], ytickname=[' ',' ',' ',' ',' ',' ',' '], $
        position=pos[7,*], $ ;xtitle='!17Pulse Phase!6', $
        xtickname=[' ','0','0.25','0.5','0.75']

  binplot, a[0,*], a[2,*], a[1,*], color=col[5], thick=tf, _EXTRA=e
  erplot, a[0,*], a[2,*], a[3,*], color=col[5], thick=tf, width=0.0


  if keyword_set(ps) then begin
    device, /close
    set_plot, odev
    print, 'Output file "' + psfile + '"'
  endif

return
end
