Pro demo1, file, BINS=bins, NOERR=noerr, ERRSTEP=errstep, _EXTRA=e
;+
; NOME:  DEMO1
;
; PURPOSE:
;       A simple plotting program:
;           Read the data from an ASCII file with 3 columns (X Y ERRY).
;           Plot the data connecting points or using bins.
;
;  OPTIONAL INPUT:
;       FILE:  data file name
;
;  KEYWORDS:
;       BINS: if TRUE then use bins (connected)
;      NOERR: if TRUE then do not plot error bars
;    ERRSTEP: if given then use it as interval for error bars plotting step
;             (def. = 10)
;    ... additionally can give all those allowed by PLOT
;
; EXAMPLES:
;       demo1
;       demo1, 'data_file.dat', /BINS, XRANGE=[-70,100]
;       demo1, 'data_file.dat', ERRSTEP=2
;
; LN 2001
;-

if N_PARAMS() ne 1 then begin    ; if no parameter given

  file = PICKFILE(FILTER='*.out')
  if file eq '' then return

            ;  file = ''
            ;  read,'Give input file: ',file
endif

a = nxyreadf(file,ncol=3)   ; read a 3 columns ASCII file

c = loadct19()              ; load a 19 colors table (index 0-18)

plot, a[0,*],a[1,*], XSTY=1, YSTY=1, THICK=2, CHARS=1.5, $
      XTIT='!6Time (s)!N', YTIT='!6Counts!N', $
      TITLE='!18SAX-GRBM !17GRB980519!N', $
      /NODATA, _EXTRA=e

if KEYWORD_SET(bins) then $   ; if a bin plot was requested
  binplot, a[0,*],a[1,*], COLOR=c[2], THICK=2, /CONNECT $
else $
  oplot, a[0,*],a[1,*], COLOR=c[2], THICK=2

if not KEYWORD_SET(noerr) then begin   ; if error bars should be plotted
                                       ; (keyword to omit them was not given)
  if N_ELEMENTS(errstep) eq 0 then errstep = 10  ; if the step was given
  erplot, a[0,*],a[1,*],a[2,*], STEP=errstep, col=c[3]
endif

return
end
