Pro demoanim3d, RATE=rate, NFRAMES=nframes, IDEMO=idemo, SHADE=shade
;+
; Demo program to show an animated drawing in 3-D
;
; USAGE:
;     demoanim3d [RATE=rate, NFRAMES=nframes, IDEMO=idemo, SHADE=shade]
;
; KEYWORDS
;      RATE: defines the start animation speed in a scale 0-100 (def.=50).
;   NFRAMES: the number of frames (in 2-64) for the animation (def.=16).
;     IDEMO: demo index in 1-4 (def.=1).
;     SHADE: if set then use SHADE_SURF instead of SURFACE to draw the surface.
;
; LN 2001
;-

; Reset any 3-D transformations that may be in use creating a dummy window.

WINDOW, /FREE, XSIZE=300, YSIZE=300

; Initialize animation: set frame size and number of frames.
sizx = 300
sizy = 300

IF NOT KEYWORD_SET(rate) THEN rate=50
IF NOT KEYWORD_SET(idemo) THEN idemo=1
IF NOT KEYWORD_SET(nframes) THEN nframes=16
IF NOT KEYWORD_SET(shade) THEN draw='SURFACE' ELSE draw='SHADE_SURF'

idemo = idemo < 4 > 1         ; in the range 1 - 4
nframes = nframes < 64 > 2    ; in the range 2 - 64


; Loop to create nframes images, rotating in the Z plane each time.
CASE idemo OF
  1: command = draw + ', DIST(40), AX = 60, AZ = i * 360. / nframes'
  2: BEGIN
     z=SHIFT(DIST(40), 20, 20)  &  z=EXP(-(z/10)^2)
     command = draw + ', z, AX = 60, AZ = i * 360. / nframes'
     END
  3: BEGIN
     z=BESELJ(SHIFT(DIST(30,20), 15, 10)/2.,0)
     command = draw + ', z, AX = 60, AZ = i * 360. / nframes'
     END
  4: BEGIN
     z=DIST(30,20)
     command = draw + ', z, AX = 60, AZ = i * 360. / nframes'
     END
ENDCASE

XINTERANIMATE, SET=[sizx, sizy, nframes]

FOR i = 0, nframes - 1 DO BEGIN 
   ERASE
   res=EXECUTE(command)
   XINTERANIMATE, FRAME=i, WINDOW=!D.WINDOW
ENDFOR 

WDELETE   ; remove the dummy window

; Run the animation.
XINTERANIMATE, rate

END
