;+
; NAME:  SCROLL_MSG
;
; PURPOSE:
;       Notifies a "scrolling" row message in a modal LABEL Widget+"Ok" BUTTON
;       Widget.  Text longer than 80 characters are truncated.
;
; CALLING SEQUENCE:
;       SCROLL_MSG, Message
;
; INPUTS:
;       Message:  The (string) message to display.
;
; OUTPUTS:
;       None.
;
; KEYWORD PARAMETERS:
;     GROUP: The widget ID of the widget that calls this program.  When this ID
;            is specified, the death of the caller results in the death of
;            this program.
;     TITLE: The title of the widget.
;      BELL: If set then ring the terminal bell.
;     XSIZE: If set gives the X size (in pixels) of the message window
;            (def.=150).
;     TIMER: If set then the window is destroyed after the given time.
;   NOFOCUS: If set then the pointer do not focus on the 'Ok' button.
;     MODAL: If set, then the program runs in "modal" mode, meaning that
;            all other widgets are blocked until the user quits this program.
;     BLOCK: Set this keyword to have XMANAGER block when this
;            application is registered.  By default the Xmanager
;            keyword NO_BLOCK is set to 1 to provide access to the
;            command line if active command  line processing is available.
;            Note that setting BLOCK for this application will cause
;            all widget applications to block, not only this application.
;
; SIDE EFFECTS:
;       Triggers the XMANAGER if it is not already in use.
;
; MODIFICATION HISTORY:
;       Written by L. Nicastro @ IFCAI-CNR, January 2001
;                (derived from "cw_notify")
;                ( Last change: 25/01/2001 )
;-

PRO scroll_msg_event, Ev
COMMON loc, xs, wl, msg

l=strlen(msg)

    for i = 0,xs/2 do begin
      WIDGET_CONTROL, wl, XOFFSET=i*2,set_value=msg
      wait,0.05
    endfor

WIDGET_CONTROL, ev.top, /DESTROY

return
END
;==


PRO scroll_msg, Message, GROUP=group, TITLE=title, BELL=bell, XSIZE=xsize, $
                TIMER=timer, NOFOCUS=nofocus, MODAL=modal, BLOCK=block, _EXTRA=e

COMMON loc, xs, wl, msg

IF KEYWORD_SET(title) THEN t = title else t = 'Message'
IF KEYWORD_SET(bell) THEN bell = STRING(7B) else bell = ''

scroll = 0
IF (N_ELEMENTS(message) ne 1) THEN BEGIN
  MESSAGE, 'Dare una stringa semplice.', /INFO
  RETURN
ENDIF

; Truncate message to 80 chars
IF STRLEN(message) GT 80 THEN msg = STRMID(message,0,80) ELSE msg = message

IF KEYWORD_SET(xsize) THEN xs = xsize ELSE xs = 150

    IF KEYWORD_SET(MODAL) AND N_ELEMENTS(GROUP) GT 0 THEN BEGIN
        mainbase = WIDGET_BASE(GROUP_LEADER = group, /MODAL)
    ENDIF ELSE BEGIN
        mainbase = WIDGET_BASE()
    ENDELSE

    a = WIDGET_BASE(TITLE=t, /COLUMN)
    c = WIDGET_BASE(a, /FRAME, XSIZE=xs)
    wl = WIDGET_LABEL(c, VALUE=message, XSIZE=150, _EXTRA=e)
    b = WIDGET_BASE(a, /ROW)
    bt = WIDGET_BUTTON(b, VALUE='OK', /FRAME, RESOURCE_NAME='OK')
    WIDGET_CONTROL, a, /REALIZE

    FOR i = 0,xs/2 DO BEGIN
      WIDGET_CONTROL, wl, XOFFSET=xs-i*2, SET_VALUE=msg
      WAIT, 0.05
    ENDFOR

    IF (NOT KEYWORD_SET(nofocus)) THEN WIDGET_CONTROL, bt, /INPUT_FOCUS
    IF N_ELEMENTS(block) EQ 0 THEN block=0

    PRINT, bell         ; ring the terminal bell
    IF KEYWORD_SET(timer) THEN WIDGET_CONTROL, a, TIMER=timer

    XMANAGER, t, a, GROUP=Group, NO_BLOCK=(NOT(FLOAT(block))), $
              EVENT_HANDLER='scroll_msg_event'

    WIDGET_CONTROL, mainbase, /DESTROY

return
END
